@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Inline;
 
-our $DATE = '2015-11-28'; # DATE
-our $VERSION = '0.31'; # VERSION
+our $DATE = '2016-01-14'; # DATE
+our $VERSION = '0.32'; # VERSION
 
 use 5.010001;
 use strict;
@@ -90,6 +90,11 @@ _
         schema  => 'bool*',
         default => 0,
     },
+    use_utf8 => {
+        summary => 'Whether to set utf8 flag on output',
+        schema  => 'bool*',
+        default => 0,
+    },
 );
 
 $SPEC{gen_inline_pericmd_script} = {
@@ -669,6 +674,10 @@ _
         push @l, 'elsif ($is_success && $is_stream) {}', "\n";
         push @l, 'else { require Perinci::Result::Format::Lite; $is_stream=0; $fres = Perinci::Result::Format::Lite::format($_pci_r->{res}, ($_pci_r->{format} // $_pci_r->{res}[3]{"cmdline.default_format"} // "text"), $_pci_r->{naked_res}, 0) }', "\n";
         push @l, "\n";
+
+        push @l, 'my $use_utf8 = $_pci_r->{res}[3]{"x.hint.result_binary"} ? 0 : '.($args{use_utf8} ? 1:0).";\n";
+        push @l, 'if ($use_utf8) { binmode STDOUT, ":utf8" }', "\n";
+
         push @l, 'if ($is_stream) {', "\n";
         push @l, '    my $code = $_pci_r->{res}[2]; if (ref($code) ne "CODE") { die "Result is a stream but no coderef provided" } if ('.(Data::Sah::Util::Type::is_simple($type) ? 1:0).') { while(defined(my $l=$code->())) { print $l; print "\n" unless "'.($type).'" eq "buf"; } } else { while (defined(my $rec=$code->())) { print _pci_json()->encode($rec),"\n" } }', "\n";
         push @l, '} else {', "\n";
@@ -819,7 +828,7 @@ Perinci::CmdLine::Inline - Generate inline Perinci::CmdLine CLI script
 
 =head1 VERSION
 
-This document describes version 0.31 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-11-28.
+This document describes version 0.32 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2016-01-14.
 
 =head1 SYNOPSIS
 
@@ -1033,6 +1042,10 @@ Currently does nothing, provided only for compatibility with Perinci::CmdLine::B
 
 Program URL.
 
+=item * B<use_utf8> => I<bool> (default: 0)
+
+Whether to set utf8 flag on output.
+
 =item * B<validate_args> => I<bool> (default: 1)
 
 Whether to validate arguments using schemas.
@@ -1091,7 +1104,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
